"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../shared/model");
var dikeClients_1 = require("../dikeClients");
var electron_1 = require("electron");
var oauth_1 = require("@ice/dike-core-js/lib/types/oauth");
var logger_1 = require("../logger");
//const OAUTH_CALLBACK_URL = 'diker://dike/OAUTH_AUTHORIZE_ISAC4';
var OAUTH_CALLBACK_URL = "://dike/OAUTH_AUTHORIZE_ISAC4";
var logger = logger_1.provideLogger('AuthenticationHandlers');
var StartAuthenticationChannel = /** @class */ (function () {
    function StartAuthenticationChannel(protocol_name) {
        this.protocol_name = protocol_name;
    }
    StartAuthenticationChannel.prototype.handleRequest = function (body) {
        console.log('Callback url StartAuthenticationChannel:', this.protocol_name + OAUTH_CALLBACK_URL);
        console.log(this.protocol_name);
        logger.info("Starting login flow");
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.getOauthUrl(this.protocol_name + OAUTH_CALLBACK_URL, oauth_1.LoginType.OIDC).then(function (oauthUrl) {
            logger.info("Opening browser o '" + oauthUrl + "'");
            var url1 = new URL(oauthUrl.url);
            console.log("🚀 ~ file: AuthenticationHandlers.ts:28 ~  url1.toString():", url1.toString());
            //console.log('oauthUrl')
            //console.dir(oauthUrl, { depth: undefined })
            return electron_1.shell.openExternal(url1.toString()).then(function () { return ({}); });
            // if (isTest) {
            //   const secondaryWindow = new BrowserWindow({ width: 600, height: 400 });
            //   secondaryWindow.loadURL(url1.toString());
            // } else {
            //   return shell.openExternal(url1.toString()).then(() => ({}));
            // }
        });
    };
    return StartAuthenticationChannel;
}());
exports.StartAuthenticationChannel = StartAuthenticationChannel;
// export class RetrieveAuthenticationChannel implements IpcHandler<void, RetrieveAuthenticationResponse> {
//   constructor(private analyticsEventHandler: AnalyticsEventHandler) { }
//   handleRequest(body: void): Promise<RetrieveAuthenticationResponse> {
//     logger.info(`Retrieving identity`);
//     const instance = DikeClients.getInstance();
//     return instance
//       .getOauthIdentity(true)
//       .catch((err) => Promise.resolve(createEmptyIdentity()))
//       .then((value) => {
//         this.analyticsEventHandler.setLogged(value.logged);
//         return {
//           identity: value,
//         };
//       });
//   }
// }
var RetrieveAuthenticationChannel = /** @class */ (function () {
    function RetrieveAuthenticationChannel(analyticsEventHandler) {
        this.analyticsEventHandler = analyticsEventHandler;
    }
    RetrieveAuthenticationChannel.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info("Retrieving identity");
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance
            .getOauthIdentity(true)
            .then(function (value) {
            // In caso di successo, setta il valore di `logged` in `analyticsEventHandler`
            _this.analyticsEventHandler.setLogged(value.logged);
            return {
                identity: value,
            };
        })
            .catch(function (err) {
            // Gestisci l'errore loggandolo e restituendo un oggetto `RetrieveAuthenticationResponse` con `createEmptyIdentity()`
            logger.error("Error retrieving identity: " + err.message, err);
            return {
                identity: model_1.createEmptyIdentity(),
                error: { message: err.message || "Unknown error", code: err.code || "ERR_UNKNOWN" } // Inserisci il messaggio e codice errore
            };
        });
    };
    return RetrieveAuthenticationChannel;
}());
exports.RetrieveAuthenticationChannel = RetrieveAuthenticationChannel;
var LogoutAuthenticationChannel = /** @class */ (function () {
    function LogoutAuthenticationChannel(analyticsEventHandler) {
        this.analyticsEventHandler = analyticsEventHandler;
    }
    LogoutAuthenticationChannel.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info("Retrieving identity");
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.getOauthLogout().then(function () {
            _this.analyticsEventHandler.setLogged(false);
            _this.analyticsEventHandler.sendGoSignWeb("Logout");
            //TODO:gestire errori
            return {};
        });
    };
    return LogoutAuthenticationChannel;
}());
exports.LogoutAuthenticationChannel = LogoutAuthenticationChannel;
var AssociationsAuthenticationChannel = /** @class */ (function () {
    function AssociationsAuthenticationChannel() {
    }
    AssociationsAuthenticationChannel.prototype.handleRequest = function (body) {
        logger.info("selecting associations");
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.selectOauthAssociations(body)
            .then(function (value) {
            return value; // Restituisci il valore in caso di successo
        })
            .catch(function (err) {
            logger.error("Error selecting associations: " + err.message, err);
            return {
                error: { message: err.message || "Unknown error", code: err.code || "ERR_UNKNOWN" }
            }; // Restituisci l'errore formattato
        });
    };
    return AssociationsAuthenticationChannel;
}());
exports.AssociationsAuthenticationChannel = AssociationsAuthenticationChannel;
/*
export class mTLSChannel implements IpcHandler<{}, {}> {

  handleRequest(body: mTLSRequest): Promise<{}> {
    logger.info(`Requesting mTLS`);
    return DikeClients.getInstance().mTLSRequest(body.url, body.reader, body.ckaid, body.pin);
  }
}
//*/
//# sourceMappingURL=AuthenticationHandlers.js.map