"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dikeClients_1 = require("../dikeClients");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var genericFsm_1 = require("../FSM/genericFsm");
var FSM_1 = require("../FSM");
var model_1 = require("../model");
var default_1 = require("../../environments/default");
var crypto = require("crypto");
var fs = require("fs");
var path = require("path");
var DECIPHER_FLOW_TYPE = flows_1.FlowType.DGS_FLOW_DECRYPT;
// WIP: akokot - add flow return type FsmMessage<DecipherDone> when ready
var DecipherFsmInitChannel = /** @class */ (function () {
    function DecipherFsmInitChannel() {
    }
    DecipherFsmInitChannel.prototype.handleRequest = function (body) {
        console.log('Decipher initialization');
        var genericFsm = genericFsm_1.GenericFsm.of(DECIPHER_FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm_1.FsmRegistry.getInstance().set(DECIPHER_FLOW_TYPE, genericFsm);
        return genericFsm.init().then(function () { return genericFsm.nextState()
            .then(function (v) { return FSM_1.fromState(v); }); });
    };
    return DecipherFsmInitChannel;
}());
exports.DecipherFsmInitChannel = DecipherFsmInitChannel;
var DecipherFsmPerformChannel = /** @class */ (function () {
    function DecipherFsmPerformChannel() {
    }
    DecipherFsmPerformChannel.prototype.handleRequest = function (body) {
        console.log("Decipher performing operation '%s'", body);
        var payload = model_1.mapToDecryptParamsInserted(body); // WIP: akokot - add payload mapping
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(DECIPHER_FLOW_TYPE);
        return genericFsm.send(flows_1.FlowEvent.DGS_EVT_DECRYPT_PARAMS_INSERTED, payload)
            .then(function (v) { return FSM_1.fromState(v); });
    };
    return DecipherFsmPerformChannel;
}());
exports.DecipherFsmPerformChannel = DecipherFsmPerformChannel;
var FileDecrypter = /** @class */ (function () {
    function FileDecrypter() {
        this.algorithm = 'aes-256-cbc';
        this.key = Buffer.from(default_1.environment.ENCRYPTION_KEY, 'utf8'); // 32 bytes
        this.iv = Buffer.from(default_1.environment.IV, 'utf8'); // 16 bytes
    }
    // Funzione per decifrare
    FileDecrypter.prototype.decrypt = function (encryptedText) {
        var decipher = crypto.createDecipheriv(this.algorithm, this.key, this.iv);
        var decrypted = decipher.update(encryptedText, 'hex', 'utf8');
        decrypted += decipher.final('utf8');
        return decrypted;
    };
    // Funzione per leggere e decifrare il file cifrato
    FileDecrypter.prototype.readAndDecryptFile = function (filePath) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            fs.readFile(filePath, 'utf8', function (err, encryptedData) {
                if (err) {
                    console.error('Errore nella lettura del file cifrato:', err);
                    reject(err);
                    return;
                }
                // Decifra i dati
                try {
                    var decryptedData = _this.decrypt(encryptedData);
                    console.log('Dati decifrati:', decryptedData);
                    resolve(decryptedData);
                }
                catch (error) {
                    console.error('Errore durante la decifratura:', error);
                    reject(error);
                }
            });
        });
    };
    return FileDecrypter;
}());
var DecipherIcssFileHandler = /** @class */ (function () {
    function DecipherIcssFileHandler() {
        this.fileDecrypter = new FileDecrypter();
    }
    DecipherIcssFileHandler.prototype.handleRequest = function (body) {
        var filePath = path.join(__dirname, '..', '..', 'icss-encrypted3.json');
        return this.fileDecrypter.readAndDecryptFile(filePath)
            .then(function (decryptedData) {
            try {
                var jsonData = JSON.parse(decryptedData); // Converte i dati decifrati in un oggetto JSON
                var codesArray = jsonData.iut; // Estrae solo l'array dei codici
                if (Array.isArray(codesArray)) {
                    return { codes: codesArray }; // Ritorna l'array dei codici
                }
                else {
                    console.error('Formato JSON non valido: "iut" non è un array');
                    return { error: 'Formato JSON non valido: "iut" non è un array' };
                }
            }
            catch (parseError) {
                console.error('Errore nel parsing del JSON:', parseError);
                return { error: 'Errore nel parsing del JSON' };
            }
        })
            .catch(function (error) {
            console.error('Errore durante la decifratura:', error);
            return { error: 'Errore durante la decifratura del file' };
        });
    };
    return DecipherIcssFileHandler;
}());
exports.DecipherIcssFileHandler = DecipherIcssFileHandler;
//# sourceMappingURL=DecipherHandlers.js.map